==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/os/gos969.h <==
/****************************************************************************

  module      : gos969.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: START/STOP/INSTALL/REMOVE ANY DATABASE_SERVER
  description : description ...


  last changed: 1999-11-08  18:11
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GOS969_H
#define GOS969_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#include "gos00.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC
APIRET os969StartAnyServerService    ( char *pszNodeName,
                                       char *pszServerName );

externC
APIRET os969StopAnyServerService     ( char *pszNodeName,
                                       char *pszServerName );

externC
APIRET os969UpdateAnyServerService   ( char *pszNodeName, 
                                       char *pszServerName, 
								       BOOL fAutostart );

externC
APIRET os969InstallAnyXserverService ( char *pszNodeName, 
                                       char *pszServerName, 
	                                   BOOL fAutostart );

externC
APIRET os969RemoveAnyXserverService  ( char *pszNodeName,
                                       char *pszServerName );

externC
APIRET os969StartAnyServer           ( char *pszCmdLine, 
                                       char *pszServerName, 
                                       char *pszServerSemaName, 
                                       BOOL fSuppressActiveMsg );

externC
APIRET os969StopAnyServer            ( char *pszServerName,
                                       char *pszServerSemName );

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GOS969_H */

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/os/gos969.h <==
/****************************************************************************

  module      : gos969.h

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: START/STOP/INSTALL/REMOVE ANY DATABASE_SERVER
  description : description ...


  last changed: 1999-11-08  18:11
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/


#ifndef GOS969_H
#define GOS969_H



/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/
#include "gos00.h"
#include "gos41.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/


/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/


/*===========================================================================*
 *  CLASSES, STRUCTURES, TYPES, UNIONS ...                                   *
 *===========================================================================*/


/*===========================================================================*
 *  FUNCTION PROTOTYPES                                                      *
 *===========================================================================*/

externC
DWORD os969StartAnyServerService    ( char *pszNodeName,
                                       char *pszServerName );

externC
DWORD os969StopAnyServerService     ( char *pszNodeName,
                                       char *pszServerName );

externC
DWORD os969UpdateAnyServerService   ( char *pszNodeName, 
                                       char *pszServerName, 
								       BOOL fAutostart );

externC
DWORD os969InstallAnyXserverService ( char *pszNodeName, 
                                       char *pszServerName, 
	                                   BOOL fAutostart );

externC
DWORD os969RemoveAnyXserverService  ( char *pszNodeName,
                                       char *pszServerName );

externC
DWORD os969StartAnyServer           ( char *pszCmdLine, 
                                       char *pszServerName, 
                                       char *pszServerSemaName, 
                                       BOOL fSuppressActiveMsg );

externC
DWORD os969StopAnyServer            ( char *pszServerName,
                                       char *pszServerSemName );

/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



#endif  /* GOS969_H */
